@@ -1,8 +1,9 @@
-from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
 from django.utils.translation import gettext_lazy as _
 
 from ... import settings
+from ...cms_plugins import CMSUIPlugin
+from ...common.attributes import AttributesMixin
 from .. import badge
 from . import forms, models
 
@@ -10,7 +11,7 @@ mixin_factory = settings.get_renderer(badge)
 
 
 @plugin_pool.register_plugin
-class BadgePlugin(mixin_factory("Badge"), CMSPluginBase):
+class BadgePlugin(mixin_factory("Badge"), AttributesMixin, CMSUIPlugin):
     """
     Components > "Badge" Plugin
     https://getbootstrap.com/docs/5.0/components/badge/
@@ -20,7 +21,7 @@ class BadgePlugin(mixin_factory("Badge"), CMSPluginBase):
     module = _("Frontend")
     model = models.Badge
     form = forms.BadgeForm
-    render_template = f"djangocms_frontend/{settings.framework}/badge.html"
+    render_template = "djangocms_frontend/badge.html"
     change_form_template = "djangocms_frontend/admin/badge.html"
     text_enabled = True
 
@@ -35,5 +36,4 @@ class BadgePlugin(mixin_factory("Badge"), CMSPluginBase):
                 )
             },
         ),
-        (_("Advanced settings"), {"classes": ("collapse",), "fields": ("attributes",)}),
     ]
