@@ -6,6 +6,7 @@ from djangocms_frontend.helpers import get_plugin_template
 from ... import settings
 from ...cms_plugins import CMSUIPlugin
 from ...common.attributes import AttributesMixin
+from ...common.background import BackgroundMixin
 from .. import carousel
 from ..link.cms_plugins import LinkPluginMixin
 from . import forms, models
@@ -13,10 +14,6 @@ from .constants import CAROUSEL_TEMPLATE_CHOICES
 
 mixin_factory = settings.get_renderer(carousel)
 
-subject_location_available = ".scale_and_crop_with_subject_location" in getattr(
-    settings.settings, "THUMBNAIL_PROCESSORS", []
-)
-
 
 @plugin_pool.register_plugin
 class CarouselPlugin(mixin_factory("Carousel"), AttributesMixin, CMSUIPlugin):
@@ -41,7 +38,11 @@ class CarouselPlugin(mixin_factory("Carousel"), AttributesMixin, CMSUIPlugin):
                     ("carousel_aspect_ratio", "carousel_interval"),
                     ("carousel_controls", "carousel_indicators"),
                     ("carousel_keyboard", "carousel_wrap"),
-                    ("carousel_ride", "carousel_pause"),
+                    ("carousel_ride",),
+                    (
+                        "carousel_transition",
+                        "carousel_pause",
+                    ),
                 )
             },
         ),
@@ -55,7 +56,11 @@ class CarouselPlugin(mixin_factory("Carousel"), AttributesMixin, CMSUIPlugin):
 
 @plugin_pool.register_plugin
 class CarouselSlidePlugin(
-    mixin_factory("CarouselSlide"), AttributesMixin, LinkPluginMixin, CMSUIPlugin
+    mixin_factory("CarouselSlide"),
+    AttributesMixin,
+    BackgroundMixin,
+    LinkPluginMixin,
+    CMSUIPlugin,
 ):
     """
     Components > "Carousel Slide" Plugin
@@ -92,10 +97,6 @@ class CarouselSlidePlugin(
         ),
     ]
 
-    def render(self, context, instance, placeholder):
-        instance.subject_location_available = subject_location_available
-        return super().render(context, instance, placeholder)
-
     def get_render_template(self, context, instance, placeholder):
         return get_plugin_template(
             instance.parent.get_plugin_instance()[0],
