@@ -121,7 +121,9 @@ def add_plugin(placeholder, plugin):
         placeholder.add_plugin(plugin)
     else:  # CMS < v4
         if plugin.parent:
-            plugin.position -= plugin.parent.position + 1  # Restart position counting at 0
+            plugin.position -= (
+                plugin.parent.position + 1
+            )  # Restart position counting at 0
         else:
             plugin.position -= 1  # 0-based counting in v3
         plugin.save()
@@ -132,6 +134,13 @@ def delete_plugin(plugin):
     return plugin.placeholder.delete_plugin(plugin)
 
 
+def is_first_child(instance, parent):
+    if hasattr(instance.placeholder, "add_plugin"):  # available as of CMS v4
+        return instance.position == parent.position + 1
+    else:
+        return instance.position == 0
+
+
 def coerce_decimal(value):
     """Force value to be converted to decimal.Decimal or return None"""
     try:
