@@ -1,12 +1,9 @@
 from django.test import TestCase
 
-from djangocms_frontend.contrib.media.models import (
-    Media, MediaBody,
-)
+from djangocms_frontend.contrib.media.models import Media, MediaBody
 
 
 class MediaModelTestCase(TestCase):
-
     def test_media_instance(self):
         instance = Media.objects.create()
         self.assertEqual(str(instance), "Media (1)")
